@@ -55,7 +55,7 @@ def get_result_df(py_filename, output_folder, start_date, end_date, para_dict):
         save_path = generate_filepath(py_filename, output_folder, start_date, end_date, para_dict, result_df.iloc[i])
         cal_performance_list.append((save_path, start_date, end_date, manager_list))
 
-    pool = mp.Pool()
+    pool = mp.Pool(processes=32)
     pool.map(mp_cal_performance, cal_performance_list)
     pool.close()
 
