@@ -1,4 +1,5 @@
 import pandas as pd
+import numpy as np
 import datetime
 import math
 
@@ -149,7 +150,8 @@ class Components:
 
         try:
             df['net_profit'] = "{:,}".format(int(round(df['net_profit'], 0)))
-            df['net_profit_to_mdd'] = round(df['net_profit_to_mdd'], 2)
+            if df['net_profit_to_mdd'] == np.inf: df['net_profit_to_mdd'] = 'inf'
+            else: df['net_profit_to_mdd'] = round(df['net_profit_to_mdd'], 2)
             df['total_commission'] = "{:,}".format(int(round(df['total_commission'] , 0)))
 
             df['mdd_dollar'] = "{:,}".format(int(round(df['mdd_dollar'], 0)))
@@ -213,7 +215,7 @@ class Components:
 
         start_date_year = datetime.datetime.strptime(start_date, '%Y-%m-%d').year
         end_date_year = datetime.datetime.strptime(end_date, '%Y-%m-%d').year
-        year_list = list(range(start_date_year, end_date_year))
+        year_list = list(range(start_date_year, end_date_year + 1))
 
         year_col1 = []
         year_col2 = []
